@@ -1,8 +1,8 @@
-#deprecation_date <- as.Date("2018-08-01")
+deprecation_date <- as.Date("2018-08-01")
 
 #' Fit a Principal Curve
 #'
-#' This function will be deprecated on August 1st, 2018.
+#' This function was deprecated on August 1st, 2018.
 #' Use \code{\link{principal_curve}} instead.
 #'
 #' @param x a matrix of points in arbitrary dimension.
@@ -36,10 +36,7 @@ principal.curve <- function(
   trace = FALSE,
   ...
 ) {
-## # This function will be deprecated on August 1st, 2018
-##  if (Sys.Date() >= deprecation_date) {
-##    .Deprecated("principal_curve", package = "princurve", old = "principal.curve")
-##  }
+  .Deprecated("principal_curve", package = "princurve", old = "principal.curve")
 
   out <- principal_curve(
     x = x,
